# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/scilint/',
                'doc_host': 'https://newday-data.github.io',
                'git_url': 'https://github.com/newday-data/scilint/tree/{branch}/',
                'lib_path': 'scilint'},
  'syms': { 'scilint.experimental.test_nbdev': { 'scilint.experimental.test_nbdev.Topics': ( 'example_nbs/experimental/nbdev.html#topics',
                                                                                             'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.Topics.__init__': ( 'example_nbs/experimental/nbdev.html#topics.__init__',
                                                                                                      'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.Topics.get_num_topics': ( 'example_nbs/experimental/nbdev.html#topics.get_num_topics',
                                                                                                            'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.Topics.get_topic_sizes': ( 'example_nbs/experimental/nbdev.html#topics.get_topic_sizes',
                                                                                                             'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.Topics.get_topics': ( 'example_nbs/experimental/nbdev.html#topics.get_topics',
                                                                                                        'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.Topics.plot_wordcloud': ( 'example_nbs/experimental/nbdev.html#topics.plot_wordcloud',
                                                                                                            'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.evaluate': ( 'example_nbs/experimental/nbdev.html#evaluate',
                                                                                               'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.fit': ( 'example_nbs/experimental/nbdev.html#fit',
                                                                                          'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.get_experiment_segment': ( 'example_nbs/experimental/nbdev.html#get_experiment_segment',
                                                                                                             'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.get_traffic_text': ( 'example_nbs/experimental/nbdev.html#get_traffic_text',
                                                                                                       'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.get_utterances': ( 'example_nbs/experimental/nbdev.html#get_utterances',
                                                                                                     'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.preprocess': ( 'example_nbs/experimental/nbdev.html#preprocess',
                                                                                                 'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.serve_num_topics': ( 'example_nbs/experimental/nbdev.html#serve_num_topics',
                                                                                                       'scilint/experimental/test_nbdev.py'),
                                                 'scilint.experimental.test_nbdev.something': ( 'example_nbs/experimental/nbdev.html#something',
                                                                                                'scilint/experimental/test_nbdev.py')},
            'scilint.exploratory.test_nbdev': { 'scilint.exploratory.test_nbdev.Topics': ( 'example_nbs/exploratory/nbdev.html#topics',
                                                                                           'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.Topics.__init__': ( 'example_nbs/exploratory/nbdev.html#topics.__init__',
                                                                                                    'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.Topics.get_num_topics': ( 'example_nbs/exploratory/nbdev.html#topics.get_num_topics',
                                                                                                          'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.Topics.get_topic_sizes': ( 'example_nbs/exploratory/nbdev.html#topics.get_topic_sizes',
                                                                                                           'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.Topics.get_topics': ( 'example_nbs/exploratory/nbdev.html#topics.get_topics',
                                                                                                      'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.Topics.plot_wordcloud': ( 'example_nbs/exploratory/nbdev.html#topics.plot_wordcloud',
                                                                                                          'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.evaluate': ( 'example_nbs/exploratory/nbdev.html#evaluate',
                                                                                             'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.fit': ( 'example_nbs/exploratory/nbdev.html#fit',
                                                                                        'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.get_experiment_segment': ( 'example_nbs/exploratory/nbdev.html#get_experiment_segment',
                                                                                                           'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.get_traffic_text': ( 'example_nbs/exploratory/nbdev.html#get_traffic_text',
                                                                                                     'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.get_utterances': ( 'example_nbs/exploratory/nbdev.html#get_utterances',
                                                                                                   'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.preprocess': ( 'example_nbs/exploratory/nbdev.html#preprocess',
                                                                                               'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.serve_num_topics': ( 'example_nbs/exploratory/nbdev.html#serve_num_topics',
                                                                                                     'scilint/exploratory/test_nbdev.py'),
                                                'scilint.exploratory.test_nbdev.something': ( 'example_nbs/exploratory/nbdev.html#something',
                                                                                              'scilint/exploratory/test_nbdev.py')},
            'scilint.indicators': { 'scilint.indicators._check_for_function_asserts': ( 'indicators.html#_check_for_function_asserts',
                                                                                        'scilint/indicators.py'),
                                    'scilint.indicators._count_func_ret_asserts': ( 'indicators.html#_count_func_ret_asserts',
                                                                                    'scilint/indicators.py'),
                                    'scilint.indicators._count_inline_asserts': ( 'indicators.html#_count_inline_asserts',
                                                                                  'scilint/indicators.py'),
                                    'scilint.indicators._incr_assert_count': ( 'indicators.html#_incr_assert_count',
                                                                               'scilint/indicators.py'),
                                    'scilint.indicators._tests_per_function_code': ( 'indicators.html#_tests_per_function_code',
                                                                                     'scilint/indicators.py'),
                                    'scilint.indicators._update_ret_vals': ('indicators.html#_update_ret_vals', 'scilint/indicators.py'),
                                    'scilint.indicators.calc_ifp': ('indicators.html#calc_ifp', 'scilint/indicators.py'),
                                    'scilint.indicators.calls_per_func': ('indicators.html#calls_per_func', 'scilint/indicators.py'),
                                    'scilint.indicators.calls_per_func_mean': ( 'indicators.html#calls_per_func_mean',
                                                                                'scilint/indicators.py'),
                                    'scilint.indicators.calls_per_func_median': ( 'indicators.html#calls_per_func_median',
                                                                                  'scilint/indicators.py'),
                                    'scilint.indicators.count_func_calls': ('indicators.html#count_func_calls', 'scilint/indicators.py'),
                                    'scilint.indicators.get_cell_code': ('indicators.html#get_cell_code', 'scilint/indicators.py'),
                                    'scilint.indicators.get_func_defs': ('indicators.html#get_func_defs', 'scilint/indicators.py'),
                                    'scilint.indicators.get_project_root': ('indicators.html#get_project_root', 'scilint/indicators.py'),
                                    'scilint.indicators.iaf': ('indicators.html#iaf', 'scilint/indicators.py'),
                                    'scilint.indicators.in_func_pct': ('indicators.html#in_func_pct', 'scilint/indicators.py'),
                                    'scilint.indicators.loc_per_md_section': ( 'indicators.html#loc_per_md_section',
                                                                               'scilint/indicators.py'),
                                    'scilint.indicators.markdown_code_pct': ('indicators.html#markdown_code_pct', 'scilint/indicators.py'),
                                    'scilint.indicators.replace_ipython_magics': ( 'indicators.html#replace_ipython_magics',
                                                                                   'scilint/indicators.py'),
                                    'scilint.indicators.safe_div': ('indicators.html#safe_div', 'scilint/indicators.py'),
                                    'scilint.indicators.tests_func_coverage_pct': ( 'indicators.html#tests_func_coverage_pct',
                                                                                    'scilint/indicators.py'),
                                    'scilint.indicators.tests_per_func_mean': ( 'indicators.html#tests_per_func_mean',
                                                                                'scilint/indicators.py'),
                                    'scilint.indicators.tests_per_function': ( 'indicators.html#tests_per_function',
                                                                               'scilint/indicators.py'),
                                    'scilint.indicators.total_code_len': ('indicators.html#total_code_len', 'scilint/indicators.py')},
            'scilint.scilint': { 'scilint.scilint._calculate_warnings': ('scilint.html#_calculate_warnings', 'scilint/scilint.py'),
                                 'scilint.scilint._get_excluded_paths': ('scilint.html#_get_excluded_paths', 'scilint/scilint.py'),
                                 'scilint.scilint._load_conf': ('scilint.html#_load_conf', 'scilint/scilint.py'),
                                 'scilint.scilint._map_paths_specs': ('scilint.html#_map_paths_specs', 'scilint/scilint.py'),
                                 'scilint.scilint._persist_results': ('scilint.html#_persist_results', 'scilint/scilint.py'),
                                 'scilint.scilint._reshape_warnings': ('scilint.html#_reshape_warnings', 'scilint/scilint.py'),
                                 'scilint.scilint.build': ('scilint.html#build', 'scilint/scilint.py'),
                                 'scilint.scilint.display_warning_report': ('scilint.html#display_warning_report', 'scilint/scilint.py'),
                                 'scilint.scilint.get_default_spec': ('scilint.html#get_default_spec', 'scilint/scilint.py'),
                                 'scilint.scilint.get_project_root': ('scilint.html#get_project_root', 'scilint/scilint.py'),
                                 'scilint.scilint.is_nbdev_project': ('scilint.html#is_nbdev_project', 'scilint/scilint.py'),
                                 'scilint.scilint.lint': ('scilint.html#lint', 'scilint/scilint.py'),
                                 'scilint.scilint.lint_nb': ('scilint.html#lint_nb', 'scilint/scilint.py'),
                                 'scilint.scilint.lint_nbs': ('scilint.html#lint_nbs', 'scilint/scilint.py'),
                                 'scilint.scilint.run_nbqa_cmd': ('scilint.html#run_nbqa_cmd', 'scilint/scilint.py'),
                                 'scilint.scilint.scilint_build': ('scilint.html#scilint_build', 'scilint/scilint.py'),
                                 'scilint.scilint.scilint_ci': ('scilint.html#scilint_ci', 'scilint/scilint.py'),
                                 'scilint.scilint.scilint_lint': ('scilint.html#scilint_lint', 'scilint/scilint.py'),
                                 'scilint.scilint.scilint_tidy': ('scilint.html#scilint_tidy', 'scilint/scilint.py'),
                                 'scilint.scilint.tidy': ('scilint.html#tidy', 'scilint/scilint.py')},
            'scilint.test.test_nbdev': { 'scilint.test.test_nbdev.Topics': ( 'example_nbs/no_spec_provided/nbdev.html#topics',
                                                                             'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.Topics.__init__': ( 'example_nbs/no_spec_provided/nbdev.html#topics.__init__',
                                                                                      'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.Topics.get_num_topics': ( 'example_nbs/no_spec_provided/nbdev.html#topics.get_num_topics',
                                                                                            'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.Topics.get_topic_sizes': ( 'example_nbs/no_spec_provided/nbdev.html#topics.get_topic_sizes',
                                                                                             'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.Topics.get_topics': ( 'example_nbs/no_spec_provided/nbdev.html#topics.get_topics',
                                                                                        'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.Topics.plot_wordcloud': ( 'example_nbs/no_spec_provided/nbdev.html#topics.plot_wordcloud',
                                                                                            'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.evaluate': ( 'example_nbs/no_spec_provided/nbdev.html#evaluate',
                                                                               'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.fit': ( 'example_nbs/no_spec_provided/nbdev.html#fit',
                                                                          'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.get_experiment_segment': ( 'example_nbs/no_spec_provided/nbdev.html#get_experiment_segment',
                                                                                             'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.get_traffic_text': ( 'example_nbs/no_spec_provided/nbdev.html#get_traffic_text',
                                                                                       'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.get_utterances': ( 'example_nbs/no_spec_provided/nbdev.html#get_utterances',
                                                                                     'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.preprocess': ( 'example_nbs/no_spec_provided/nbdev.html#preprocess',
                                                                                 'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.serve_num_topics': ( 'example_nbs/no_spec_provided/nbdev.html#serve_num_topics',
                                                                                       'scilint/test/test_nbdev.py'),
                                         'scilint.test.test_nbdev.something': ( 'example_nbs/no_spec_provided/nbdev.html#something',
                                                                                'scilint/test/test_nbdev.py')},
            'scilint.test.test_nbdev_high_quality': { 'scilint.test.test_nbdev_high_quality.Topics': ( 'example_nbs/nbdev_high_quality.html#topics',
                                                                                                       'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.Topics.__init__': ( 'example_nbs/nbdev_high_quality.html#topics.__init__',
                                                                                                                'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.Topics.get_num_topics': ( 'example_nbs/nbdev_high_quality.html#topics.get_num_topics',
                                                                                                                      'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.Topics.get_topic_sizes': ( 'example_nbs/nbdev_high_quality.html#topics.get_topic_sizes',
                                                                                                                       'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.Topics.get_topics': ( 'example_nbs/nbdev_high_quality.html#topics.get_topics',
                                                                                                                  'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.Topics.plot_wordcloud': ( 'example_nbs/nbdev_high_quality.html#topics.plot_wordcloud',
                                                                                                                      'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.echo': ( 'example_nbs/nbdev_high_quality.html#echo',
                                                                                                     'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.evaluate': ( 'example_nbs/nbdev_high_quality.html#evaluate',
                                                                                                         'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.fit': ( 'example_nbs/nbdev_high_quality.html#fit',
                                                                                                    'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.get_experiment_segment': ( 'example_nbs/nbdev_high_quality.html#get_experiment_segment',
                                                                                                                       'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.get_traffic_text': ( 'example_nbs/nbdev_high_quality.html#get_traffic_text',
                                                                                                                 'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.get_utterances': ( 'example_nbs/nbdev_high_quality.html#get_utterances',
                                                                                                               'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.preprocess': ( 'example_nbs/nbdev_high_quality.html#preprocess',
                                                                                                           'scilint/test/test_nbdev_high_quality.py'),
                                                      'scilint.test.test_nbdev_high_quality.serve_num_topics': ( 'example_nbs/nbdev_high_quality.html#serve_num_topics',
                                                                                                                 'scilint/test/test_nbdev_high_quality.py')},
            'scilint.validated.test_nbdev_high_quality': { 'scilint.validated.test_nbdev_high_quality.Topics': ( 'example_nbs/validated/nbdev_high_quality.html#topics',
                                                                                                                 'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.Topics.__init__': ( 'example_nbs/validated/nbdev_high_quality.html#topics.__init__',
                                                                                                                          'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.Topics.get_num_topics': ( 'example_nbs/validated/nbdev_high_quality.html#topics.get_num_topics',
                                                                                                                                'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.Topics.get_topic_sizes': ( 'example_nbs/validated/nbdev_high_quality.html#topics.get_topic_sizes',
                                                                                                                                 'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.Topics.get_topics': ( 'example_nbs/validated/nbdev_high_quality.html#topics.get_topics',
                                                                                                                            'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.Topics.plot_wordcloud': ( 'example_nbs/validated/nbdev_high_quality.html#topics.plot_wordcloud',
                                                                                                                                'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.echo': ( 'example_nbs/validated/nbdev_high_quality.html#echo',
                                                                                                               'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.evaluate': ( 'example_nbs/validated/nbdev_high_quality.html#evaluate',
                                                                                                                   'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.fit': ( 'example_nbs/validated/nbdev_high_quality.html#fit',
                                                                                                              'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.get_experiment_segment': ( 'example_nbs/validated/nbdev_high_quality.html#get_experiment_segment',
                                                                                                                                 'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.get_traffic_text': ( 'example_nbs/validated/nbdev_high_quality.html#get_traffic_text',
                                                                                                                           'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.get_utterances': ( 'example_nbs/validated/nbdev_high_quality.html#get_utterances',
                                                                                                                         'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.preprocess': ( 'example_nbs/validated/nbdev_high_quality.html#preprocess',
                                                                                                                     'scilint/validated/test_nbdev_high_quality.py'),
                                                           'scilint.validated.test_nbdev_high_quality.serve_num_topics': ( 'example_nbs/validated/nbdev_high_quality.html#serve_num_topics',
                                                                                                                           'scilint/validated/test_nbdev_high_quality.py')}}}
